==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/TomorrowExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TomorrowExpressionDescription } from "./TomorrowExpressionDescription";
/**
 * @hidden
 */
var TomorrowExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TomorrowExpressionDescriptionMetadata, _super);
    function TomorrowExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TomorrowExpressionDescriptionMetadata.b = function (a) {
        if (TomorrowExpressionDescriptionMetadata.a == null) {
            TomorrowExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TomorrowExpressionDescriptionMetadata.c(TomorrowExpressionDescriptionMetadata.a);
        }
        if (a.k(TomorrowExpressionDescriptionMetadata.a)) {
            return;
        }
        a.ab(TomorrowExpressionDescriptionMetadata.a);
    };
    TomorrowExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    TomorrowExpressionDescriptionMetadata.d = function (a) {
        TomorrowExpressionDescriptionMetadata.b(a);
        a.ad("TomorrowExpression", function () { return new TomorrowExpressionDescription(); });
        a.ac("TomorrowExpression", TomorrowExpressionDescriptionMetadata.a);
    };
    TomorrowExpressionDescriptionMetadata.$t = markType(TomorrowExpressionDescriptionMetadata, 'TomorrowExpressionDescriptionMetadata');
    TomorrowExpressionDescriptionMetadata.a = null;
    return TomorrowExpressionDescriptionMetadata;
}(Base));
export { TomorrowExpressionDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/TomorrowExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TomorrowExpressionDescription } from "./TomorrowExpressionDescription";
/**
 * @hidden
 */
var TomorrowExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TomorrowExpressionDescriptionMetadata, _super);
    function TomorrowExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TomorrowExpressionDescriptionMetadata.b = function (a) {
        if (TomorrowExpressionDescriptionMetadata.a == null) {
            TomorrowExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TomorrowExpressionDescriptionMetadata.c(TomorrowExpressionDescriptionMetadata.a);
        }
        if (a.k(TomorrowExpressionDescriptionMetadata.a)) {
            return;
        }
        a.ac(TomorrowExpressionDescriptionMetadata.a);
    };
    TomorrowExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    TomorrowExpressionDescriptionMetadata.d = function (a) {
        TomorrowExpressionDescriptionMetadata.b(a);
        a.ae("TomorrowExpression", function () { return new TomorrowExpressionDescription(); });
        a.ad("TomorrowExpression", TomorrowExpressionDescriptionMetadata.a);
    };
    TomorrowExpressionDescriptionMetadata.$t = markType(TomorrowExpressionDescriptionMetadata, 'TomorrowExpressionDescriptionMetadata');
    TomorrowExpressionDescriptionMetadata.a = null;
    return TomorrowExpressionDescriptionMetadata;
}(Base));
export { TomorrowExpressionDescriptionMetadata };
